@@ -235,25 +235,25 @@ void App_WithDoc_Gtk::update_window_title()
   }
 }
 
-void App_WithDoc_Gtk::ui_warning(const Glib::ustring& text)
+void App_WithDoc_Gtk::ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text)
 {
-  GtkDialogs::ui_warning(text);
+  GtkDialogs::ui_warning(*this, text, secondary_text);
 }
 
-Glib::ustring App_WithDoc_Gtk::ui_file_select_open()
+Glib::ustring App_WithDoc_Gtk::ui_file_select_open(const Glib::ustring& starting_folder_uri)
 {
-  return GtkDialogs::ui_file_select_open();
+  return GtkDialogs::ui_file_select_open(*this, starting_folder_uri);
 }
 
 Glib::ustring App_WithDoc_Gtk::ui_file_select_save(const Glib::ustring& old_file_uri)
 {
-  return GtkDialogs::ui_file_select_save(old_file_uri);
+  return GtkDialogs::ui_file_select_save(*this, old_file_uri);
 }
 
 void App_WithDoc_Gtk::ui_show_modification_status()
 {
   bool modified = m_pDocument->get_modified();
-  
+
   //Enable Save and SaveAs menu items:
   if(m_action_save)
     m_action_save->property_sensitive() = modified; //TODO: Use a set_sensitive(modified)?
@@ -265,18 +265,13 @@ void App_WithDoc_Gtk::ui_show_modification_status()
 
 App_WithDoc_Gtk::enumSaveChanges App_WithDoc_Gtk::ui_offer_to_save_changes()
 {
-  return GtkDialogs::ui_offer_to_save_changes(m_pDocument->get_file_uri());
-}
-
-bool App_WithDoc_Gtk::ui_ask_overwrite(const std::string& file_uri)
-{
-  return GtkDialogs::ui_ask_overwrite(m_pDocument->get_file_uri());
+  return GtkDialogs::ui_offer_to_save_changes(*this, m_pDocument->get_file_uri());
 }
 
 void App_WithDoc_Gtk::document_history_add(const Glib::ustring& file_uri)
-{ 
+{
   if(m_recent_files_model && !file_uri.empty())
-  { 
+  {
     //TODO: Wrap gnome_vfs_escape_path_string() in gnome-vfsmm.
     //Glib::ustring filename_e = Gnome::Vfs::escape_path_string(file_uri);
     Glib::ustring uri = file_uri; // "file://" + filename_e;
