@@ -19,6 +19,8 @@
 #ifndef BAKERY_VIEWBASE_H
 #define BAKERY_VIEWBASE_H
 
+#include <sigc++/trackable.h>
+
 namespace Bakery
 {
 
@@ -26,7 +28,7 @@ namespace Bakery
  * This allows the App to call load_from_document() and save_to_document(),
  * without knowing exactly what type of document the view uses.
  */
-class ViewBase
+class ViewBase : virtual public sigc::trackable
 {
 public: 
   ViewBase();
